@@ -1,7 +1,6 @@
 #ifndef KEYBINDINGS_H
 #define KEYBINDINGS_H
 
-#include <SDL/SDL.h>
 #include <map>
 #include <string>
 
@@ -333,6 +332,12 @@ enum InterfaceKeyType
 	INTERFACEKEY_A_JUMP,
 	INTERFACEKEY_A_HOLD,
 	INTERFACEKEY_A_TALK,
+	INTERFACEKEY_A_ASSUME_IDENTITY_NEW,
+	INTERFACEKEY_A_ASSUME_IDENTITY_NONE,
+	INTERFACEKEY_A_ASSUME_IDENTITY_NAME,
+	INTERFACEKEY_A_ASSUME_IDENTITY_ORIGIN,
+	INTERFACEKEY_A_ASSUME_IDENTITY_PROFESSION,
+	INTERFACEKEY_A_ASSUME_IDENTITY_WORSHIP,
 	INTERFACEKEY_A_INTERACT,
 	INTERFACEKEY_A_ACTION,
 	INTERFACEKEY_A_ACTION_CREATE,
@@ -409,6 +414,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_A_LOG_AGREEMENTS,
 	INTERFACEKEY_A_LOG_EVENTS,
 	INTERFACEKEY_A_LOG_BESTIARY,
+	INTERFACEKEY_A_LOG_ARTIFACTS,
 	INTERFACEKEY_A_LOG_FILTER,
 	INTERFACEKEY_A_LOG_ZOOM_CURRENT_LOCATION,
 	INTERFACEKEY_A_LOG_ZOOM_SELECTED,
@@ -418,6 +424,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_A_BARTER_CURRENCY_1,
 	INTERFACEKEY_A_BARTER_CURRENCY_2,
 	INTERFACEKEY_A_BARTER_TRADE,
+	INTERFACEKEY_A_BARTER_SHOW,
 
 	EMBARKKEY_START,
 	INTERFACEKEY_SETUP_EMBARK=EMBARKKEY_START,
@@ -451,6 +458,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_CHOOSE_NAME_RANDOM,
 	INTERFACEKEY_CHOOSE_NAME_CLEAR,
 	INTERFACEKEY_CHOOSE_NAME_TYPE,
+	INTERFACEKEY_CHOOSE_NAME_FIRST,
 	INTERFACEKEY_SETUPGAME_NEW,
 	INTERFACEKEY_SETUPGAME_VIEW,
 	INTERFACEKEY_SETUPGAME_CUSTOMIZE_UNIT,
@@ -560,6 +568,8 @@ enum InterfaceKeyType
 	INTERFACEKEY_BUILDJOB_RACKSTAND_KILL1,
 	INTERFACEKEY_BUILDJOB_RACKSTAND_DEFAULTS2,
 	INTERFACEKEY_BUILDJOB_RACKSTAND_KILL2,
+	INTERFACEKEY_BUILDJOB_DISPLAY_FURNITURE_SET,
+	INTERFACEKEY_BUILDJOB_DISPLAY_FURNITURE_CANCEL,
 	INTERFACEKEY_HOTKEY_BUILDING_ARMORSTAND,
 	INTERFACEKEY_HOTKEY_BUILDING_BED,
 	INTERFACEKEY_HOTKEY_BUILDING_CHAIR,
@@ -602,6 +612,7 @@ enum InterfaceKeyType
 	INTERFACEKEY_HOTKEY_BUILDING_NEST_BOX,
 	INTERFACEKEY_HOTKEY_BUILDING_BOOKCASE,
 	INTERFACEKEY_HOTKEY_BUILDING_HIVE,
+	INTERFACEKEY_HOTKEY_BUILDING_DISPLAY_FURNITURE,
 	INTERFACEKEY_HOTKEY_BUILDING_MACHINE_SCREW_PUMP,
 	INTERFACEKEY_HOTKEY_BUILDING_MACHINE_WATER_WHEEL,
 	INTERFACEKEY_HOTKEY_BUILDING_MACHINE_WINDMILL,
@@ -1251,6 +1262,17 @@ enum InterfaceKeyType
 	INTERFACEKEY_IMAGE_CREATOR_FILTER,
 	INTERFACEKEY_IMAGE_CREATOR_NAME,
 	INTERFACEKEY_IMAGE_CREATOR_DONE,
+	INTERFACEKEY_CIV_RAID,
+	INTERFACEKEY_CIV_CENTER_ON_FORT,
+	INTERFACEKEY_CIV_REMOVE_MISSION,
+	INTERFACEKEY_CIV_RESCUE,
+	INTERFACEKEY_CIV_RECOVER,
+	INTERFACEKEY_CIV_WORLD,
+	INTERFACEKEY_CIV_MISSIONS,
+	INTERFACEKEY_CIV_NEWS,
+	INTERFACEKEY_CIV_PEOPLE,
+	INTERFACEKEY_CIV_ARTIFACTS,
+	INTERFACEKEY_CIV_CIVS,
 
 	MILITIAKEY_START,
 	INTERFACEKEY_D_MILITARY_CREATE_SQUAD=MILITIAKEY_START,
@@ -1579,6 +1601,8 @@ enum InterfaceKeyType
 	INTERFACEKEYNUM,
 };
 
+#include <SDL/SDL.h>
+
 extern bimap<InterfaceKey,std::string> bindingNames;
 extern bimap<InterfaceKey,std::string> displayNames;
 extern bimap<SDLKey,std::string> sdlNames;
